@@ -2,7 +2,10 @@
 # Magic Keys
 #
 
-DB='default'
+DB_NAME='nauto'
+DATE_COL='daily_ts'
+DATE_UNIQ='serial_number'
+
 cAlias='|'
 kAbove='above'
 kArgs='args'
